==> cscec5b-rmat-impl-3.0.1-20221025.085610-22-sources.jar: com/ejianc/business/rmat/bean/ExitSupplierEntity.java <==
package com.ejianc.business.rmat.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 退场劳务队明细
 * 
 * @author generator
 * 
 */
 @TableName("ejc_rmat_exit_supplier")
public class ExitSupplierEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="exit_id")
    private Long exitId; // 退场主键ID
    @TableField(value="material_id")
    private Long materialId; // 物资主键
    @TableField(value="material_source_id")
    private String materialSourceId; // 物资来源主键
    @TableField(value="material_name")
    private String materialName; // 物资名称
    @TableField(value="material_type_id")
    private Long materialTypeId; // 物资类别
    @TableField(value="material_type_name")
    private String materialTypeName; // 物资类别名称
    @TableField(value="material_code")
    private String materialCode; // 物料编码
    @TableField(value="spec")
    private String spec; // 规格型号
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value="rent_unit_id")
    private String rentUnitId; // 计租单位id
    @TableField(value="rent_unit_name")
    private String rentUnitName; // 计租单位
    @TableField(value="unit_id")
    private String unitId; // 档案单位id
    @TableField(value="unit_name")
    private String unitName; // 档案单位
    @TableField(value="real_unit_id")
    private String realUnitId; // 实物单位id
    @TableField(value="real_unit_name")
    private String realUnitName; // 实物单位
    @TableField(value="num")
    private BigDecimal num; // 档案数量
    @TableField(value="rent_num")
    private BigDecimal rentNum; // 计租数量
    @TableField(value="real_num")
    private BigDecimal realNum; // 实物数量
    @TableField(value="rent_trans_scale")
    private BigDecimal rentTransScale; // 计租转换系数
    @TableField(value="real_trans_scale")
    private BigDecimal realTransScale; // 实物转换系数
    @TableField(value="rent_out_num")
    private BigDecimal rentOutNum; // 计租退场数量
    @TableField(value="real_out_num")
    private BigDecimal realOutNum; // 实物退场数量
    @TableField(value="supplier_id")
    private Long supplierId; // 设备供应商
    @TableField(value="supplier_name")
    private String supplierName; // 供应商名称
    @TableField(value="supplier_source_id")
    private String supplierSourceId; // 供应商来源ID
    
    
    

    public Long getExitId() {
        return exitId;
    }

    public void setExitId(Long exitId) {
        this.exitId = exitId;
    }
    public Long getMaterialId() {
        return materialId;
    }

    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }
    public String getMaterialSourceId() {
        return materialSourceId;
    }

    public void setMaterialSourceId(String materialSourceId) {
        this.materialSourceId = materialSourceId;
    }
    public String getMaterialName() {
        return materialName;
    }

    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }
    public Long getMaterialTypeId() {
        return materialTypeId;
    }

    public void setMaterialTypeId(Long materialTypeId) {
        this.materialTypeId = materialTypeId;
    }
    public String getMaterialTypeName() {
        return materialTypeName;
    }

    public void setMaterialTypeName(String materialTypeName) {
        this.materialTypeName = materialTypeName;
    }
    public String getMaterialCode() {
        return materialCode;
    }

    public void setMaterialCode(String materialCode) {
        this.materialCode = materialCode;
    }
    public String getSpec() {
        return spec;
    }

    public void setSpec(String spec) {
        this.spec = spec;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public String getRentUnitId() {
        return rentUnitId;
    }

    public void setRentUnitId(String rentUnitId) {
        this.rentUnitId = rentUnitId;
    }
    public String getRentUnitName() {
        return rentUnitName;
    }

    public void setRentUnitName(String rentUnitName) {
        this.rentUnitName = rentUnitName;
    }
    public String getUnitId() {
        return unitId;
    }

    public void setUnitId(String unitId) {
        this.unitId = unitId;
    }
    public String getUnitName() {
        return unitName;
    }

    public void setUnitName(String unitName) {
        this.unitName = unitName;
    }
    public String getRealUnitId() {
        return realUnitId;
    }

    public void setRealUnitId(String realUnitId) {
        this.realUnitId = realUnitId;
    }
    public String getRealUnitName() {
        return realUnitName;
    }

    public void setRealUnitName(String realUnitName) {
        this.realUnitName = realUnitName;
    }
    public BigDecimal getNum() {
        return num;
    }

    public void setNum(BigDecimal num) {
        this.num = num;
    }
    public BigDecimal getRentNum() {
        return rentNum;
    }

    public void setRentNum(BigDecimal rentNum) {
        this.rentNum = rentNum;
    }
    public BigDecimal getRealNum() {
        return realNum;
    }

    public void setRealNum(BigDecimal realNum) {
        this.realNum = realNum;
    }
    public BigDecimal getRentTransScale() {
        return rentTransScale;
    }

    public void setRentTransScale(BigDecimal rentTransScale) {
        this.rentTransScale = rentTransScale;
    }
    public BigDecimal getRealTransScale() {
        return realTransScale;
    }

    public void setRealTransScale(BigDecimal realTransScale) {
        this.realTransScale = realTransScale;
    }
    public BigDecimal getRentOutNum() {
        return rentOutNum;
    }

    public void setRentOutNum(BigDecimal rentOutNum) {
        this.rentOutNum = rentOutNum;
    }
    public BigDecimal getRealOutNum() {
        return realOutNum;
    }

    public void setRealOutNum(BigDecimal realOutNum) {
        this.realOutNum = realOutNum;
    }
    public Long getSupplierId() {
        return supplierId;
    }

    public void setSupplierId(Long supplierId) {
        this.supplierId = supplierId;
    }
    public String getSupplierName() {
        return supplierName;
    }

    public void setSupplierName(String supplierName) {
        this.supplierName = supplierName;
    }
    public String getSupplierSourceId() {
        return supplierSourceId;
    }

    public void setSupplierSourceId(String supplierSourceId) {
        this.supplierSourceId = supplierSourceId;
    }
    
}

==> cscec5b-rmat-impl-3.0.1-20230609.071328-202-sources.jar: com/ejianc/business/rmat/bean/ExitSupplierEntity.java <==
package com.ejianc.business.rmat.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 退场劳务队明细
 * 
 * @author generator
 * 
 */
 @TableName("ejc_rmat_exit_supplier")
public class ExitSupplierEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="exit_id")
    private Long exitId; // 退场主键ID
    @TableField(value="exit_detail_id")
    private Long exitDetailId; // 退场明细主键ID
    @TableField(value="material_id")
    private Long materialId; // 物资主键
    @TableField(value="material_source_id")
    private String materialSourceId; // 物资来源主键
    @TableField(value="material_name")
    private String materialName; // 物资名称
    @TableField(value="material_type_id")
    private Long materialTypeId; // 物资类别
    @TableField(value="material_type_name")
    private String materialTypeName; // 物资类别名称
    @TableField(value="material_code")
    private String materialCode; // 物料编码
    @TableField(value="spec")
    private String spec; // 规格型号
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value="rent_unit_id")
    private String rentUnitId; // 计租单位id
    @TableField(value="rent_unit_name")
    private String rentUnitName; // 计租单位
    @TableField(value="unit_id")
    private String unitId; // 档案单位id
    @TableField(value="unit_name")
    private String unitName; // 档案单位
    @TableField(value="real_unit_id")
    private String realUnitId; // 实物单位id
    @TableField(value="real_unit_name")
    private String realUnitName; // 实物单位
    @TableField(value="num")
    private BigDecimal num; // 档案数量
    @TableField(value="rent_num")
    private BigDecimal rentNum; // 计租数量
    @TableField(value="real_num")
    private BigDecimal realNum; // 实物数量
    @TableField(value="rent_trans_scale")
    private BigDecimal rentTransScale; // 计租转换系数
    @TableField(value="real_trans_scale")
    private BigDecimal realTransScale; // 实物转换系数
    @TableField(value="rent_out_num")
    private BigDecimal rentOutNum; // 计租退场数量
    @TableField(value="real_out_num")
    private BigDecimal realOutNum; // 实物退场数量
    @TableField(value="rent_record_outNum")
    private BigDecimal rentRecordOutNum; // 计租退场档案数量
    @TableField(value="supplier_id")
    private Long supplierId; // 设备供应商
    @TableField(value="supplier_name")
    private String supplierName; // 供应商名称
    @TableField(value="supplier_source_id")
    private String supplierSourceId; // 供应商来源ID
    
    
    

    public Long getExitId() {
        return exitId;
    }

    public void setExitId(Long exitId) {
        this.exitId = exitId;
    }
    public Long getMaterialId() {
        return materialId;
    }

    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }
    public String getMaterialSourceId() {
        return materialSourceId;
    }

    public void setMaterialSourceId(String materialSourceId) {
        this.materialSourceId = materialSourceId;
    }
    public String getMaterialName() {
        return materialName;
    }

    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }
    public Long getMaterialTypeId() {
        return materialTypeId;
    }

    public void setMaterialTypeId(Long materialTypeId) {
        this.materialTypeId = materialTypeId;
    }
    public String getMaterialTypeName() {
        return materialTypeName;
    }

    public void setMaterialTypeName(String materialTypeName) {
        this.materialTypeName = materialTypeName;
    }
    public String getMaterialCode() {
        return materialCode;
    }

    public void setMaterialCode(String materialCode) {
        this.materialCode = materialCode;
    }
    public String getSpec() {
        return spec;
    }

    public void setSpec(String spec) {
        this.spec = spec;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public String getRentUnitId() {
        return rentUnitId;
    }

    public void setRentUnitId(String rentUnitId) {
        this.rentUnitId = rentUnitId;
    }
    public String getRentUnitName() {
        return rentUnitName;
    }

    public void setRentUnitName(String rentUnitName) {
        this.rentUnitName = rentUnitName;
    }
    public String getUnitId() {
        return unitId;
    }

    public void setUnitId(String unitId) {
        this.unitId = unitId;
    }
    public String getUnitName() {
        return unitName;
    }

    public void setUnitName(String unitName) {
        this.unitName = unitName;
    }
    public String getRealUnitId() {
        return realUnitId;
    }

    public void setRealUnitId(String realUnitId) {
        this.realUnitId = realUnitId;
    }
    public String getRealUnitName() {
        return realUnitName;
    }

    public void setRealUnitName(String realUnitName) {
        this.realUnitName = realUnitName;
    }
    public BigDecimal getNum() {
        return num;
    }

    public void setNum(BigDecimal num) {
        this.num = num;
    }
    public BigDecimal getRentNum() {
        return rentNum;
    }

    public void setRentNum(BigDecimal rentNum) {
        this.rentNum = rentNum;
    }
    public BigDecimal getRealNum() {
        return realNum;
    }

    public void setRealNum(BigDecimal realNum) {
        this.realNum = realNum;
    }
    public BigDecimal getRentTransScale() {
        return rentTransScale;
    }

    public void setRentTransScale(BigDecimal rentTransScale) {
        this.rentTransScale = rentTransScale;
    }
    public BigDecimal getRealTransScale() {
        return realTransScale;
    }

    public void setRealTransScale(BigDecimal realTransScale) {
        this.realTransScale = realTransScale;
    }
    public BigDecimal getRentOutNum() {
        return rentOutNum;
    }

    public void setRentOutNum(BigDecimal rentOutNum) {
        this.rentOutNum = rentOutNum;
    }
    public BigDecimal getRealOutNum() {
        return realOutNum;
    }

    public void setRealOutNum(BigDecimal realOutNum) {
        this.realOutNum = realOutNum;
    }
    public Long getSupplierId() {
        return supplierId;
    }

    public void setSupplierId(Long supplierId) {
        this.supplierId = supplierId;
    }
    public String getSupplierName() {
        return supplierName;
    }

    public void setSupplierName(String supplierName) {
        this.supplierName = supplierName;
    }
    public String getSupplierSourceId() {
        return supplierSourceId;
    }

    public void setSupplierSourceId(String supplierSourceId) {
        this.supplierSourceId = supplierSourceId;
    }

    public Long getExitDetailId() {
        return exitDetailId;
    }

    public void setExitDetailId(Long exitDetailId) {
        this.exitDetailId = exitDetailId;
    }

    public BigDecimal getRentRecordOutNum() {
        return rentRecordOutNum;
    }

    public void setRentRecordOutNum(BigDecimal rentRecordOutNum) {
        this.rentRecordOutNum = rentRecordOutNum;
    }
}
